@@ -52,3 +52,35 @@ class IdentitySSOAuthentication(authentication.BaseAuthentication):
         user, _ = User.objects.get_or_create(username=user_info["user"]["username"])
         request.session["username"] = user.username
         return (user, None)
+
+
+class IdentityAPIKeyAuthentication(authentication.BaseAuthentication):
+    """
+    This authentication is used when a user API key is sent
+    When the client doesnt have the local session, we try to authenticate it on the ID service
+    and create local session based on that
+    """
+
+    def authenticate(self, request):
+        api_key = request.META.get("HTTP_X_USER_API_KEY")
+        if not api_key:
+            # auth not attempted
+            return None
+        user_info_reply = requests.post(
+            f"{settings.IDENTITY_HOST}/internal/api_keys/validate/",
+            json={"api_key": api_key},
+        )
+
+        try:
+            user_info_reply.raise_for_status()
+        except requests.exceptions.HTTPError as e:
+            message = (
+                "User info request failed",
+                e.response.status_code,
+                e.response.content,
+            )
+            raise exceptions.AuthenticationFailed(message)
+        user_info = user_info_reply.json()
+        user, _ = User.objects.get_or_create(username=user_info["user"]["username"])
+        request.session["username"] = user.username
+        return (user, None)
