@@ -11,22 +11,19 @@ from django.http import HttpResponseRedirect, HttpResponse, HttpResponseBadReque
 
 
 def include_auth_urls():
-    return include([
-        path(r'login/', login),
-        path(r'logout/', logout)
-    ])
+    return include([path(r"login/", login), path(r"logout/", logout)])
+
 
 def include_internal_urls():
-    return include([
-        path(r'sessions/flush/', flush_session_view),
-    ])
+    return include([path(r"sessions/flush/", flush_session_view),])
+
 
 @api_view(["GET"])
 @authentication_classes([])
 def login(request):
     auth_redirect_url: str = request.build_absolute_uri().split("?")[0]
     # since the app is running in container, no way to know its on ssl
-    auth_redirect_url = auth_redirect_url.replace('http', 'https')
+    auth_redirect_url = auth_redirect_url.replace("http", "https")
     auth_code: str = request.query_params.get("code", "")
     app_redirect_url: str = request.query_params.get("state", "")
 
@@ -49,7 +46,7 @@ def login(request):
             "Auth request failed with status %s: %s; %s",
             e.response.status_code,
             e.response.content,
-            auth_redirect_url
+            auth_redirect_url,
         )
         return HttpResponse(f"Unauthorized: {message}", status=401)
 
@@ -66,7 +63,7 @@ def login(request):
             "Auth request failed with status %s: %s; %s",
             e.response.status_code,
             e.response.content,
-            tokens["access_token"]
+            tokens["access_token"],
         )
         return HttpResponse(f"Unauthorized: {message}", status=401)
 
@@ -87,14 +84,15 @@ def logout(request):
     response.delete_cookie("sso_shared_session")
     return response
 
+
 @api_view(["POST"])
 @authentication_classes([])
 def flush_session_view(request):
-    '''
+    """
     this is supposed to be served under a protected router only accessible from inside the network
     :param request:
     :return:
-    '''
+    """
     email = request.data["email"]
     try:
         user = User.objects.get(email=email)
